﻿using Microsoft.Extensions.DependencyInjection;
using Microsoft.Extensions.Logging;

namespace ConsoleApp2.Services.ErrorRecorder;

public class ErrorRecorderFactory
{
    private readonly ILogger<ErrorRecorderFactory> _logger;

    public ErrorRecorderFactory(ILogger<ErrorRecorderFactory> logger)
    {
        _logger = logger;
    }
    
    public OutputErrorRecorder CreateOutput(string database) => new(database, _logger);
    public TransformErrorRecorder CreateTransform() => new(_logger);
    public InputErrorRecorder CreateInput() => new(_logger);
}

public static class ErrorRecorderFactoryExtensions
{
    public static IServiceCollection AddErrorRecorderFactory(this IServiceCollection services)
    {
        services.AddSingleton<ErrorRecorderFactory>();
        return services;
    }
}